@@ -462,20 +462,23 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
         return new ResultsStream(QStringLiteral("PackageKitStream-upgradeable"), kTransform<QVector<AbstractResource*>>(upgradeablePackages())); //No need for it to be a PKResultsStream
     } else if (filter.state == AbstractResource::Installed) {
         auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-installed"));
-        auto f = [this, stream] {
+        auto f = [this, stream, filter] {
             const auto toResolve = kFilter<QVector<AbstractResource*>>(m_packages.packages, needsResolveFilter);
 
+            auto installedAndNameFilter = [filter] (AbstractResource *res) {
+                return res->state() >= AbstractResource::Installed && (res->name().contains(filter.search) || res->packageName() == filter.search);
+            };
             if (!toResolve.isEmpty()) {
                 resolvePackages(kTransform<QStringList>(toResolve, [] (AbstractResource* res) { return res->packageName(); }));
-                connect(m_resolveTransaction, &PKResolveTransaction::allFinished, this, [stream, toResolve] {
-                    const auto resolved = kFilter<QVector<AbstractResource*>>(toResolve, installedFilter);
+                connect(m_resolveTransaction, &PKResolveTransaction::allFinished, this, [stream, toResolve, installedAndNameFilter] {
+                    const auto resolved = kFilter<QVector<AbstractResource*>>(toResolve, installedAndNameFilter);
                     if (!resolved.isEmpty())
                         Q_EMIT stream->resourcesFound(resolved);
                     stream->finish();
                 });
             }
 
-            const auto resolved = kFilter<QVector<AbstractResource*>>(m_packages.packages, installedFilter);
+            const auto resolved = kFilter<QVector<AbstractResource*>>(m_packages.packages, installedAndNameFilter);
             if (!resolved.isEmpty()) {
                 QTimer::singleShot(0, this, [resolved, toResolve, stream] () {
                     if (!resolved.isEmpty())
@@ -703,7 +706,6 @@ void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
 {
     if (!m_updatesPackageId.isEmpty()) {
         resolvePackages(kTransform<QStringList>(m_updatesPackageId, [](const QString &pkgid) { return PackageKit::Daemon::packageName(pkgid); }));
-        fetchDetails(m_updatesPackageId);
     }
 
     m_updater->setProgressing(false);
@@ -723,11 +725,22 @@ bool PackageKitBackend::isPackageNameUpgradeable(const PackageKitResource* res)
     return !upgradeablePackageId(res).isEmpty();
 }
 
+// Copy of Transaction::packageName that doesn't create a copy but just pass a reference
+// It's an optimisation as there's a bunch of allocations that happen from packageName
+// Having packageName return a QStringRef or a QStringView would fix this issue.
+// TODO Qt 6: Have packageName and similars return a QStringView
+static QStringRef TransactionpackageName(const QString &packageID)
+{
+    QStringRef ret;
+    ret = packageID.leftRef(packageID.indexOf(QLatin1Char(';')));
+    return ret;
+}
+
 QString PackageKitBackend::upgradeablePackageId(const PackageKitResource* res) const
 {
-    QString name = res->packageName();
-    foreach (const QString& pkgid, m_updatesPackageId) {
-        if (PackageKit::Daemon::packageName(pkgid) == name)
+    const QString name = res->packageName();
+    for (const QString& pkgid : m_updatesPackageId) {
+        if (TransactionpackageName(pkgid) == name)
             return pkgid;
     }
     return QString();
