@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #ifndef ABSTRACTRESOURCE_H
 #define ABSTRACTRESOURCE_H
@@ -69,19 +55,20 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString displayOrigin READ displayOrigin CONSTANT)
     Q_PROPERTY(int size READ size NOTIFY sizeChanged)
     Q_PROPERTY(QString sizeDescription READ sizeDescription NOTIFY sizeChanged)
-    Q_PROPERTY(QString installedVersion READ installedVersion NOTIFY stateChanged)
-    Q_PROPERTY(QString availableVersion READ availableVersion NOTIFY stateChanged)
+    Q_PROPERTY(QString installedVersion READ installedVersion NOTIFY versionsChanged)
+    Q_PROPERTY(QString availableVersion READ availableVersion NOTIFY versionsChanged)
     Q_PROPERTY(QString section READ section CONSTANT)
     Q_PROPERTY(QStringList mimetypes READ mimetypes CONSTANT)
     Q_PROPERTY(AbstractResourcesBackend* backend READ backend CONSTANT)
-    Q_PROPERTY(Rating* rating READ rating NOTIFY ratingFetched)
+    Q_PROPERTY(QVariant rating READ ratingVariant NOTIFY ratingFetched)
     Q_PROPERTY(QString appstreamId READ appstreamId CONSTANT)
     Q_PROPERTY(QString categoryDisplay READ categoryDisplay CONSTANT)
     Q_PROPERTY(QUrl url READ url CONSTANT)
     Q_PROPERTY(QString executeLabel READ executeLabel CONSTANT)
     Q_PROPERTY(QString sourceIcon READ sourceIcon CONSTANT)
     Q_PROPERTY(QString author READ author CONSTANT)
-    Q_PROPERTY(QDate releaseDate READ releaseDate NOTIFY stateChanged)
+    Q_PROPERTY(QDate releaseDate READ releaseDate NOTIFY versionsChanged)
+    Q_PROPERTY(QString upgradeText READ upgradeText NOTIFY versionsChanged)
     public:
         /**
          * This describes the state of the resource
@@ -194,6 +181,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
          * @returns the rating for the resource or null if not available
          */
         Rating* rating() const;
+        QVariant ratingVariant() const;
 
         /**
          * @returns a string defining the categories the resource belongs to
@@ -218,6 +206,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
 
         virtual QSet<QString> alternativeAppstreamIds() const { return {}; }
 
+        virtual QString upgradeText() const;
+
     public Q_SLOTS:
         virtual void fetchScreenshots();
         virtual void fetchChangelog() = 0;
@@ -229,6 +219,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
         void stateChanged();
         void ratingFetched();
         void longDescriptionChanged();
+        void versionsChanged();
 
         ///response to the fetchScreenshots method
         ///@p thumbnails and @p screenshots should have the same number of elements
