@@ -1,20 +1,7 @@
 /*
- *   Copyright (C) 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library/Lesser General Public License
- *   version 2, or (at your option) any later version, as published by the
- *   Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library/Lesser General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include <resources/StandardBackendUpdater.h>
@@ -24,10 +11,8 @@
 #include <Transaction/Transaction.h>
 #include <Transaction/TransactionModel.h>
 #include <KLocalizedString>
-#include <QDateTime>
 #include "libdiscover_debug.h"
 #include "utils.h"
-#include <QTimer>
 #include <QIcon>
 
 StandardBackendUpdater::StandardBackendUpdater(AbstractResourcesBackend* parent)
@@ -160,7 +145,8 @@ void StandardBackendUpdater::refreshProgress()
     }
 
     int allProgresses = (m_toUpgrade.size() - m_pendingResources.size()) * 100;
-    for (auto t: transactions()) {
+    const auto allTransactions = transactions();
+    for (auto t: allTransactions) {
         allProgresses += t->progress();
     }
     setProgress(allProgresses / m_toUpgrade.size());
