@@ -1,25 +1,10 @@
-/***************************************************************************
- *   Copyright © 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "NotifierItem.h"
-#include <KStatusNotifierItem>
 #include <KLocalizedString>
 #include <QMenu>
 #include <QDebug>
@@ -30,6 +15,7 @@ KStatusNotifierItem::ItemStatus sniStatus(DiscoverNotifier::State state)
         case DiscoverNotifier::Offline:
         case DiscoverNotifier::NoUpdates:
             return KStatusNotifierItem::Passive;
+        case DiscoverNotifier::Busy:
         case DiscoverNotifier::NormalUpdates:
         case DiscoverNotifier::SecurityUpdates:
         case DiscoverNotifier::RebootRequired:
@@ -38,7 +24,6 @@ KStatusNotifierItem::ItemStatus sniStatus(DiscoverNotifier::State state)
     return KStatusNotifierItem::Active;
 }
 
-
 NotifierItem::NotifierItem()
 {
 }
@@ -53,7 +38,11 @@ void NotifierItem::setupNotifierItem()
     connect(&m_notifier, &DiscoverNotifier::stateChanged, this, &NotifierItem::refresh);
 
     connect(m_item, &KStatusNotifierItem::activateRequested, &m_notifier, [this]() {
-        m_notifier.showDiscoverUpdates();
+        if (m_notifier.needsReboot()) {
+            m_notifier.reboot();
+        } else {
+            m_notifier.showDiscoverUpdates();
+        }
     });
 
     QMenu* menu = new QMenu;
@@ -68,6 +57,9 @@ void NotifierItem::setupNotifierItem()
     connect(refreshAction, &QAction::triggered, &m_notifier, &DiscoverNotifier::recheckSystemUpdateNeeded);
 
     auto f = [menu, this]() {
+        m_item->setTitle(i18n("Restart to apply installed updates"));
+        m_item->setToolTipTitle(i18n("Click to restart the device"));
+        m_item->setIconByName(QStringLiteral("view-refresh"));
         auto refreshAction = menu->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Restart..."));
         connect(refreshAction, &QAction::triggered, &m_notifier, &DiscoverNotifier::recheckSystemUpdateNeeded);
     };
